#ifndef _DMA_TEST_H
#define _DMA_TEST_H

#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <fcntl.h>
#include <time.h>
#include <unistd.h>
#include <strings.h>
#include <errno.h>
#include <ctype.h>
#include <time.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/time.h>

#include "global.h"

/// \brief кол-во каналов, учавствующих в тесте
#define COUNT_CH (8+1)
/// \brief шахматка
#define CHESS_DATA          0xAAAA
/// \brief обратная шахматка
#define REVERSE_CHESS_DATA  0x5555
/// \brief индекс канала КШ в массиве параметров
#define BC_CH_INDEX         0

///
/// \brief The SConfigCh struct каналы, готовые к работе
/// 0 - КШ, 1 - ОУ1 ...
///
struct SConfigCh {
    int mIsReady[COUNT_CH];     ///< признак готовности канала
    int mIsRemote[COUNT_CH];    ///< признак удалённо управляемого канала
};
///
/// \brief The TStatChCTest1 struct статистика канала
///
struct TStatChCTest1 {
    int mDmaBlk;    ///< кол-во дма блоков
    int mErr;       ///< кол-во дма блоков, с ошибкой
};
///
/// \brief The TStatCTest1 struct статистика теста
///
struct TStatCTest1 {
    struct TStatChCTest1 mCh[COUNT_CH];     ///< поканальная статистика
};

///
/// \brief The TParamCTest1 struct параметры теста 1
///
struct TParamCTest1 {
    int mDurationHours;     ///< продолжительность теста - часы
    int mDurationMinutes;   ///< продолжительность теста - минуты
    int mLine;              ///< линия: 0-A; 1-B
    char mNames[COUNT_CH][CHANNEL_NAME_LENGTH];
    int mBcInt;
};
/// \brief неиспользуемй канал
#define NULL_DEV    "NULL"
/// \brief удаленно-управляемый канал
#define REMOTE_DEV  "REMOTE"
#define FALSE_VAL   0
#define TRUE_VAL    (~(FALSE_VAL))

///< продолжительность теста - часы
#define T_CTEST1_DURATION_H     "duration_h"
///< продолжительность теста - минуты
#define T_CTEST1_DURATION_M     "duration_m"
///< линия
#define T_CTEST1_LINE           "line"
///< КШ
#define T_CTEST1_BC             "bc"
///< ОУ1
#define T_CTEST1_RT1            "rt1"
///< ОУ2
#define T_CTEST1_RT2            "rt2"
///< ОУ3
#define T_CTEST1_RT3            "rt3"
///< ОУ4
#define T_CTEST1_RT4            "rt4"
///< ОУ5
#define T_CTEST1_RT5            "rt5"
///< ОУ6
#define T_CTEST1_RT6            "rt6"
///< ОУ7
#define T_CTEST1_RT7            "rt7"
///< ОУ8
#define T_CTEST1_RT8            "rt8"
///< показывать прерывания кш
#define T_CTEST1_BCINT          "bcint"


extern char configFileName[];                   ///< имя файла конфигурации, считанного из аргументов
extern char fullConfigFileName[];               ///< полное имя файла конфигурации в папке config
extern struct TParamCTest1 params;              ///< параметры теста 1
extern struct TMil1553Channel* channels;        ///< каналы
extern struct TMil1553Device* devices;          ///< девайсы
extern struct SConfigCh configChannels;         ///< конфигкрация готовности каналов
extern struct TStatCTest1 statTest;             ///< статистика теста

///
/// \brief main точка входа в программу
/// \param argc кол-во аргументов
/// \param argv аргументы
/// \return код возврата
///
int main(int argc, char* argv[]);
///
/// \brief constructFullConfigFileName построить полное имя файла конфигурации
/// \param fullname полное имя
/// \param size размер
/// \param name имя
///
void constructFullConfigFileName(char* fullname, int size, char* name);
///
/// \brief readConfigFile чтение конфигурации из файла
/// \param fullname полное имя файла конфигурации
/// \param params параметры теста
/// \return код результата
///
int readConfigFile(char* fullname, struct TParamCTest1* params);
///
/// \brief procCTest1 процедура консольного теста 1
/// \param params параметры теста
///
void procCTest1(struct TParamCTest1 params);
///
/// \brief initLogCTest1 настройка логов теста 1
///
void initLogCTest1(void);
///
/// \brief initDefaultParamsCTest1 инициализация параметров ао-умолчанию теста 1
/// \param params параметры теста
///
void initDefaultParamsCTest1(struct TParamCTest1* params);

#endif // _DMA_TEST_H
